==> akonadi-search_15.08.2.orig.tar.xz: akonadi-search-15.08.2/agent/abstractindexer.cpp <==
/*
 * Copyright 2013  Daniel Vrátil <dvratil@redhat.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "abstractindexer.h"

AbstractIndexer::AbstractIndexer()
{
}

AbstractIndexer::~AbstractIndexer()
{
}

void AbstractIndexer::move(const Akonadi::Item::Id &item,
                           const Akonadi::Entity::Id &from,
                           const Akonadi::Entity::Id &to)
{
    Q_UNUSED(item);
    Q_UNUSED(from);
    Q_UNUSED(to);
}

void AbstractIndexer::updateFlags(const Akonadi::Item &item,
                                  const QSet<QByteArray> &addedFlags,
                                  const QSet<QByteArray> &removed)
{
    Q_UNUSED(item);
    Q_UNUSED(addedFlags);
    Q_UNUSED(removed);
}

==> akonadi-search_15.12.3.orig.tar.xz: akonadi-search-15.12.3/agent/abstractindexer.cpp <==
/*
 * Copyright 2013  Daniel Vrátil <dvratil@redhat.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "abstractindexer.h"

AbstractIndexer::AbstractIndexer()
{
}

AbstractIndexer::~AbstractIndexer()
{
}

void AbstractIndexer::move(const Akonadi::Item::Id &item,
                           const Akonadi::Collection::Id &from,
                           const Akonadi::Collection::Id &to)
{
    Q_UNUSED(item);
    Q_UNUSED(from);
    Q_UNUSED(to);
}

void AbstractIndexer::updateFlags(const Akonadi::Item &item,
                                  const QSet<QByteArray> &addedFlags,
                                  const QSet<QByteArray> &removed)
{
    Q_UNUSED(item);
    Q_UNUSED(addedFlags);
    Q_UNUSED(removed);
}
